<h1 align="center">
  Pocket TRC20
</h1>
<p align="center">
  PocketTRC20 is a Python TRON blockchain explorer which is used to get details of crypto transactions in the TRC20 network. It uses the official <a href="https://tronscan.org/#/">TRON API</a> for scanning transactions.
</p>

### [Project's wiki](https://github.com/codelao/PocketTRC20/wiki)
**or:**
`git clone https://github.com/codelao/PocketTRC20.wiki.git`

#### Contents
- [Home](https://github.com/codelao/PocketTRC20/wiki)
  - [Welcome to PocketTRC20's wiki!](https://github.com/codelao/PocketTRC20/wiki#welcome-to-pockettrc20s-wiki)
    - [Description](https://github.com/codelao/PocketTRC20/wiki#description)
- [Getting started](https://github.com/codelao/PocketTRC20/wiki/Getting-started)
  - [Using PocketTRC20 as a CLI app](https://github.com/codelao/PocketTRC20/wiki/Getting-started#using-pockettrc20-as-a-cli-app)
  - [Using PocketTRC20 as a Python module](https://github.com/codelao/PocketTRC20/wiki/Getting-started#using-pockettrc20-as-a-python-module)
- [Installation](https://github.com/codelao/PocketTRC20/wiki/Installation)
  - [Install via pip](https://github.com/codelao/PocketTRC20/wiki/Installation#install-via-pip)
